@@ -41,9 +41,11 @@ class WavefrontClient(connection_handler.ConnectionHandler,
 
     REPORT_END_POINT = '/report'
     EVENT_END_POINT = '/api/v2/event'
+    HTTP_TIMEOUT = 60.0
 
     def __init__(self, server, token, max_queue_size=50000, batch_size=10000,
-                 flush_interval_seconds=5, enable_internal_metrics=True):
+                 flush_interval_seconds=5, enable_internal_metrics=True,
+                 queue_impl=queue.Queue):
         # pylint: disable=too-many-arguments,too-many-statements
         """Construct Direct Client.
 
@@ -68,17 +70,17 @@ class WavefrontClient(connection_handler.ConnectionHandler,
         self._batch_size = batch_size
         self._flush_interval_seconds = flush_interval_seconds
         self._default_source = socket.gethostname() or 'unknown'
-        self._metrics_buffer = queue.Queue(max_queue_size)
-        self._histograms_buffer = queue.Queue(max_queue_size)
-        self._tracing_spans_buffer = queue.Queue(max_queue_size)
-        self._spans_log_buffer = queue.Queue(max_queue_size)
-        self._events_buffer = queue.Queue(max_queue_size)
+        self._metrics_buffer = queue_impl(max_queue_size)
+        self._histograms_buffer = queue_impl(max_queue_size)
+        self._tracing_spans_buffer = queue_impl(max_queue_size)
+        self._spans_log_buffer = queue_impl(max_queue_size)
+        self._events_buffer = queue_impl(max_queue_size)
         self._headers = {'Content-Type': 'application/octet-stream',
                          'Content-Encoding': 'gzip'}
         self._event_headers = {'Content-Type': 'application/json',
                                'Content-Encoding': 'gzip'}
         self._closed = False
-        self._schedule_lock = threading.Lock()
+        self._schedule_lock = threading.RLock()
         self._timer = None
         self._schedule_timer()
 
@@ -191,13 +193,15 @@ class WavefrontClient(connection_handler.ConnectionHandler,
                 response = requests.post(self.server + self.EVENT_END_POINT,
                                          params=None,
                                          headers=self._event_headers,
-                                         data=points)
+                                         data=points,
+                                         timeout=self.HTTP_TIMEOUT)
             else:
                 params = {'f': data_format}
                 compressed_data = utils.gzip_compress(points.encode('utf-8'))
                 response = requests.post(self.server + self.REPORT_END_POINT,
                                          params=params, headers=self._headers,
-                                         data=compressed_data)
+                                         data=compressed_data,
+                                         timeout=self.HTTP_TIMEOUT)
 
             self._sdk_metrics_registry.new_delta_counter(
                 f'{entity_prefix}.report.{response.status_code}').inc()
@@ -325,7 +329,7 @@ class WavefrontClient(connection_handler.ConnectionHandler,
             self._points_invalid.inc()
             raise error
         try:
-            self._metrics_buffer.put(line_data)
+            self._metrics_buffer.put_nowait(line_data)
         except queue.Full as error:
             self._points_dropped.inc()
             raise error
@@ -376,7 +380,7 @@ class WavefrontClient(connection_handler.ConnectionHandler,
             self._histograms_invalid.inc()
             raise error
         try:
-            self._histograms_buffer.put(line_data)
+            self._histograms_buffer.put_nowait(line_data)
         except queue.Full as error:
             self._histograms_dropped.inc()
             raise error
@@ -437,20 +441,20 @@ class WavefrontClient(connection_handler.ConnectionHandler,
             self._spans_invalid.inc()
             raise error
         try:
-            self._tracing_spans_buffer.put(line_data)
+            self._tracing_spans_buffer.put_nowait(line_data)
         except queue.Full as error:
             self._spans_dropped.inc()
             raise error
         if span_logs:
             try:
                 line_data = utils.span_log_to_line_data(trace_id, span_id,
-                                                        span_logs)
+                                                        span_logs, line_data)
                 self._span_logs_valid.inc()
             except ValueError as error:
                 self._span_logs_invalid.inc()
                 raise error
             try:
-                self._spans_log_buffer.put(line_data)
+                self._spans_log_buffer.put_nowait(line_data)
             except queue.Full as error:
                 self._span_logs_dropped.inc()
                 raise error
@@ -523,7 +527,7 @@ class WavefrontClient(connection_handler.ConnectionHandler,
             self._events_invalid.inc()
             raise error
         try:
-            self._events_buffer.put(line_data)
+            self._events_buffer.put_nowait(line_data)
         except queue.Full as error:
             self._events_dropped.inc()
             raise error
